@@ -39,9 +39,11 @@ screenshot_load_config (gboolean clipboard_arg,
                         gboolean area_arg,
                         gboolean include_border_arg,
                         gboolean disable_border_arg,
+                        gboolean include_pointer_arg,
                         const gchar *border_effect_arg,
                         guint delay_arg,
-                        gboolean interactive_arg)
+                        gboolean interactive_arg,
+                        const gchar *file_arg)
 {
   static gboolean initialized = FALSE;
   ScreenshotConfig *config;
@@ -71,6 +73,13 @@ screenshot_load_config (gboolean clipboard_arg,
   config->settings = g_settings_new ("org.gnome.gnome-screenshot");
   if (config->interactive)
     {
+      if (clipboard_arg)
+        g_warning ("Option --clipboard is ignored in interactive mode.");
+      if (include_pointer_arg)
+        g_warning ("Option --include-pointer is ignored in interactive mode.");
+      if (file_arg)
+        g_warning ("Option --file is ignored in interactive mode.");
+
       config->save_dir =
         g_settings_get_string (config->settings,
                                LAST_SAVE_DIRECTORY_KEY);
@@ -87,12 +96,16 @@ screenshot_load_config (gboolean clipboard_arg,
       if (disable_border_arg)
         config->include_border = FALSE;
 
+      config->include_pointer =
+        g_settings_get_boolean (config->settings,
+                                INCLUDE_POINTER_KEY);
+
       if (border_effect_arg != NULL)
+        config->border_effect = g_strdup (border_effect_arg);
+      else
         config->border_effect =
           g_settings_get_string (config->settings,
                                  BORDER_EFFECT_KEY);
-      else
-        config->border_effect = g_strdup (border_effect_arg);
     }
   else
     {
@@ -102,18 +115,18 @@ screenshot_load_config (gboolean clipboard_arg,
       config->delay = delay_arg;
       config->include_border = include_border_arg;
       config->include_border = !disable_border_arg;
+      config->include_pointer = include_pointer_arg;
       if (border_effect_arg != NULL)
         config->border_effect = g_strdup (border_effect_arg);
 
       config->copy_to_clipboard = clipboard_arg;
+      if (file_arg != NULL)
+        config->file = g_file_new_for_commandline_arg (file_arg);
     }
 
   config->include_icc_profile =
     g_settings_get_boolean (config->settings,
                             INCLUDE_ICC_PROFILE);
-  config->include_pointer =
-    g_settings_get_boolean (config->settings,
-                            INCLUDE_POINTER_KEY);
 
   if (config->border_effect == NULL)
     config->border_effect = g_strdup ("none");
