@@ -29,6 +29,7 @@ typedef struct {
   GSettings *settings;
 
   gchar *save_dir;
+  GFile *file;
 
   gboolean copy_to_clipboard;
 
@@ -53,9 +54,11 @@ gboolean screenshot_load_config (gboolean clipboard_arg,
                                  gboolean area_arg,
                                  gboolean include_border_arg,
                                  gboolean disable_border_arg,
+                                 gboolean include_pointer_arg,
                                  const gchar *border_effect_arg,
                                  guint delay_arg,
-                                 gboolean interactive_arg);
+                                 gboolean interactive_arg,
+                                 const gchar *file_arg);
 void screenshot_save_config      (void);
 
 G_END_DECLS
